# NC State Jobs Board Package

## Requirements

The following versions of PHP are supported:

* PHP 5.3
* PHP 5.4

## Install

Via Composer

``` json
{
    "repositories": [
        {
            "type": "vcs",
            "url": "git@github.ncsu.edu:ncstate-contrib/jobs.git"
        }
    ],
    "require": {
        "ncsu/jobs": "dev-master"
    }
}
```

## Usage

**Fetching the entire Atom feed**
```php
$jobs = new Jobs();

foreach ($jobs as $job) {
	echo $job->id . PHP_EOL;
	echo $job->ouc . PHP_EOL;
	echo $job->department . PHP_EOL;
	echo $job->content . PHP_EOL;
}
```

**Filtering by OUC**
```php
$jobs = new Jobs();

$filteredJobs = $jobs->withOuc(110308)->get();

foreach ($filteredJobs as $job) {
	// Only contains jobs in OUC: 110308
}
```

**Filtering by OUCs starting with a value:**

This is useful for retrieving all units in an organization or something like that.

```php
$jobs = new Jobs();

$filteredJobs = $jobs->withOucStartingWith(11)->get();

foreach ($filteredJobs as $job) {
	// Only contains jobs with an OUC starting with "11": 110308, 11xxxx
}
```

**Filtering by department name**

Probably best to use OUC, but this is available. It's exact match so... not the most useful thing
in the world.

```php
$jobs = new Jobs();

$filteredJobs = $jobs->withDepartment('Kannapolis Research')->get();

foreach ($filteredJobs as $job) {
	// Only contains jobs with department exactly matching
	// "Kannapolis Research"
}
```

**"Full-text Searching"**

Allows you to search for keywords in the `department` or `content` fields.

```php
$jobs = new Jobs();

$filteredJobs = $jobs->searchFor('Kannapolis')->get();

foreach ($filteredJobs as $job) {
	// Only contains jobs with "content" or
	// "department" containing "Kannapolis"
}
```

**Chaining filters together**

This can be pretty powerful and useful to build searchable pages that are pre-filtered
to a subset of the jobs board. Perhaps you want to make a searchable jobs board for any
job in an OUC starting with "24"...

```php
$jobs = new Jobs();
$results = $jobs->withOucStartingWith(24)
	->searchFor('START Program')
	->get();

foreach ($results as $result) {
	// Only contains jobs with OUC starting with "24" and also
	// matching the full-text search "Start Program"
}
```

## Support

Bugs and feature request are tracked on [GitHub](https://github.ncsu.edu/mdwheele/jobs/issues)

## License

This package is released under the MIT License. See the bundled [LICENSE](LICENSE) file for details.
