<?php

namespace NCSU\Jobs;

use Illuminate\Support\Collection;
use Zend\Feed\Reader\Reader as ZendReader;
use Zend\Http\Client as ZendClient;

class Jobs
{
    private $feedUrl = 'https://jobs.ncsu.edu/all_jobs.atom';

    private $feed;

    /**
     * @var array
     */
    private $filters;

    public function __construct()
    {
        $client = new ZendClient('', array(
            'adapter' => 'Zend\Http\Client\Adapter\Curl',
            'curloptions' => array(CURLOPT_SSL_VERIFYPEER => false),
        ));
        ZendReader::setHttpClient($client);
        $this->feed = ZendReader::import($this->feedUrl());

        $this->filters = array(
            'ouc' => array(),
            'ouc-starts-with' => array(),
            'department' => array(),
            'fulltext' => array()
        );
    }

    /**
     * @return Collection
     */
    public function all()
    {
        $jobs = array();

        foreach ($this->feed as $entry) {
            $jobs[] = Job::fromAtom($entry);
        }

        return new Collection($jobs);
    }

    public function withOuc($ouc)
    {
        $this->filters['ouc'][] = $ouc;

        return $this;
    }

    public function withOucStartingWith($ouc)
    {
        $this->filters['ouc-starts-with'][] = $ouc;

        return $this;
    }

    public function withDepartment($department)
    {
        $this->filters['department'][] = $department;

        return $this;
    }

    public function searchFor($fulltext)
    {
        $this->filters['fulltext'][] = $fulltext;

        return $this;
    }

    /**
     * @return Job[]
     */
    public function get()
    {
        return $this->all()->filter(function ($job) {
            foreach ($this->filters['ouc'] as $ouc) {
                if ($job->ouc != $ouc) {
                    return false;
                }
            }

            foreach ($this->filters['ouc-starts-with'] as $oucPrefix) {
                if ( ! starts_with($job->ouc, $oucPrefix)) {
                    return false;
                }
            }

            foreach ($this->filters['department'] as $department) {
                if ($job->department != $department) {
                    return false;
                }
            }

            foreach ($this->filters['fulltext'] as $fulltext) {
                if ( ! str_contains($job->department, $fulltext) and ! str_contains($job->content, $fulltext)) {
                    return false;
                }
            }

            return true;
        });
    }

    public function feedUrl()
    {
        return $this->feedUrl;
    }
}
