<?php


use NCSU\Jobs\Jobs;

class JobsTest extends \PHPUnit_Framework_TestCase
{

    /** @test */
    public function it_fetches_atom_feed_correctly()
    {
        $jobs = new Jobs();
        $this->assertEquals('https://jobs.ncsu.edu/all_jobs.atom', $jobs->feedUrl());
        $this->assertTrue(count($jobs->all()) > 0);
    }

    /** @test */
    public function it_should_filter_by_ouc()
    {
        $jobs = new Jobs();
        $jobsFromOuc = $jobs->withOuc(110308)->get();

        foreach ($jobsFromOuc as $job) {
            $this->assertEquals(110308, $job->ouc);
        }
    }

    /** @test */
    public function it_should_filter_by_ouc_beginning_with()
    {
        $jobs = new Jobs();
        $jobsFromOuc = $jobs->withOucStartingWith(11)->get();

        foreach ($jobsFromOuc as $job) {
            $this->assertTrue(starts_with($job->ouc, 11));
        }
    }

    /** @test */
    public function it_should_filter_by_department()
    {
        $jobs = new Jobs();
        $jobsFromDepartment = $jobs->withDepartment('Kannapolis Research')->get();

        foreach ($jobsFromDepartment as $job) {
            $this->assertEquals('Kannapolis Research', $job->department);
        }
    }

    /** @test */
    public function it_should_be_searchable_across_fields()
    {
        $jobs = new Jobs();
        $results = $jobs->searchFor('Kannapolis')->get();

        $this->assertTrue(count($results) > 0);
    }

    /** @test */
    public function it_should_be_able_to_chain_constraints()
    {
        $jobs = new Jobs();
        $results = $jobs->withOucStartingWith(24)->searchFor('START Program')->get();

        foreach ($results as $result) {
            $this->assertContains('24', $result->ouc);
            $this->assertContains('START Program', $result->content);
        }
    }
} 